.. fpv-gcc documentation master file, created by
   sphinx-quickstart on Wed Jul 27 23:12:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


fpvgcc
======

.. include:: ../README.rst
    :start-after: inclusion-marker-do-not-remove

.. raw:: latex

       \vspace*{\fill}

.. tabularcolumns:: >{\raggedleft\arraybackslash}\Y{0.1} >{\raggedright\arraybackslash}\Y{0.5}

.. list-table::
    :widths: 8 40
    :header-rows: 0


    * -
        .. figure:: _static/logo_packed.png
                :align: right
      -
        .. raw:: latex

            \vspace{-1.5em}

        ``fpvgcc`` is part of the EBS universe of packages and tools for constrained embedded systems

.. raw:: latex

      \clearpage


Documentation
-------------

.. toctree::
   :maxdepth: 3

   installation
   usage
   api


.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
